@@ -3,7 +3,7 @@
 #include <skalibs/strerr2.h>
 #include "exlsn.h"
 
-#define USAGE "define [ -n ] [ -s ] [ -C | -c ] [ -d delim ] key value prog..."
+#define USAGE "define [ -N | -n ] [ -s ] [ -C | -c ] [ -d delim ] key value prog..."
 
 int main (int argc, char const **argv, char const *const *envp)
 {
